# -*- coding: utf-8 -*-
from setuphelpers import *
from setupdevhelpers import *

def update_package():
    # Declaring local variables
    package_updated = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name

    lang = control.locale
    # Translating locale
    if "en" in lang:
        lang = "en-US"
    if "es" in lang:
        lang = "es-ES"

    arch_dict = {"x64": "linux64", "x86": "linux", "all": "linux"}

    download_url = requests.head(
        "https://download.mozilla.org/?product=firefox-latest-ssl&os=%s&lang=%s" % (arch_dict[control.architecture], lang), proxies=proxies
    ).headers["Location"]

    latest_bin = download_url.rsplit("/", 1)[1].replace("%20", " ")
    version = latest_bin.split("-")[1].split(".tar")[0]

    version_from_api = (
        wgets("https://product-details.mozilla.org/1.0/firefox_versions.json", proxies=proxies, as_json=True)
        .get("LATEST_FIREFOX_VERSION", "0")
    )

    if Version(version_from_api) > Version(version):
        error('Version retrieved from the API is higher than the downloaded file')

    # Downloading latest binaries
    print(f"Latest {app_name} version is: {version}")
    print(f"Download URL is: {download_url}")
    if not isfile(latest_bin):
        print(f"Downloading: {latest_bin}")
        wget(download_url, latest_bin, proxies=proxies)
    else:
        print(f"Binary is present: {latest_bin}")

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print(f"Software version updated (from: {control.get_software_version()} to: {Version(version)})")
        package_updated = True
    else:
        print(f"Software version up-to-date ({Version(version)})")

    for f in glob.glob(f'*.tar.xz'):
        if f != latest_bin:
            remove_file(f)

    control.set_software_version(version)
    control.save_control_to_wapt()

    return package_updated